build_fractional_sum

Function build_fractional_sum 

fn build_fractional_sum<F: Field>(
    maybe_numerator_desc: Option<MleDescription<F>>,
    denominator_desc: MleDescription<F>,
    layers: &mut Vec<LayerDescriptionEnum<F>>,
) -> (Option<MleDescription<F>>, MleDescription<F>)
Given two MLEs of the same length representing the numerators and denominators of a sequence of fractions, add layers that perform a sum of the fractions, return a new pair of length-1 MLEs representing the numerator and denominator of the sum.

Setting maybe_numerator_desc to None indicates that the numerator has the same length as denominator_desc and takes the constant value 1.