pub struct LookupConstraint {
id: NodeId,
pub table_node_id: NodeId,
constrained_node_id: NodeId,
multiplicities_node_id: NodeId,
}Expand description
Represents the use of a lookup into a particular table (represented by a LookupTable).
Fields
id: NodeIdtable_node_id: NodeIdThe id of the LookupTable (lookup table) that we are a lookup up into.
constrained_node_id: NodeIdThe id of the node that is being constrained by this lookup.
multiplicities_node_id: NodeIdThe id of the node that provides the multiplicities for the constrained data.
Implementations
Sourceimpl LookupConstraint
impl LookupConstraint
Sourcepub fn new(
lookup_table: &LookupTable,
constrained: &dyn CircuitNode,
multiplicities: &dyn CircuitNode,
) -> Self
pub fn new( lookup_table: &LookupTable, constrained: &dyn CircuitNode, multiplicities: &dyn CircuitNode, ) -> Self
Creates a new LookupConstraint, constraining the data of constrained to form a subset of
the data in lookup_table with multiplicities given by multiplicities. Caller is
responsible for the yielding of all nodes (including constrained and multiplicities).
The adding of lookup specific verifier-challenge- and output layers is handled automatically
by LookupTable::generate_lookup_circuit_description.
Requires:
if constrained has length not a power of two, then multiplicitites must also count the
implicit padding!