pub struct LookupTable {
id: NodeId,
constraints: Vec<LookupConstraint>,
table_node_id: NodeId,
fiat_shamir_challenge_node_id: NodeId,
}Expand description
Represents a table of data that can be looked up into, e.g. for a range check.
Implements “Improving logarithmic derivative lookups using GKR” (2023) by Papini & Haböck. Note
that (as is usual e.g. in permutation checks) we do not check that the product of the
denominators is nonzero. This means the soundness of logUp is bounded by
|F| / max{num_constrained_values, num_table_values}.
To adapt this to a small field setting, consider using Fermat’s Little Theorem.
For a more detailed description of the soundness argument for the above, see https://www.notion.so/LogUp-ext-f846956acc3640a68bad51f7897fe32f?pvs=4#15b68687d27e807fae3fcdff59791174
Fields
id: NodeIdconstraints: Vec<LookupConstraint>The lookups that are performed on this table (will be automatically populated, via LookupTable::add_lookup_constraint, during layout).
table_node_id: NodeIdThe id of the node providing the table entries.
fiat_shamir_challenge_node_id: NodeIdThe ID of the FiatShamirChallengeNode for the FS challenge.
Implementations
Sourceimpl LookupTable
impl LookupTable
Sourcepub fn new(
table: &dyn CircuitNode,
fiat_shamir_challenge_node: &FiatShamirChallengeNode,
) -> Self
pub fn new( table: &dyn CircuitNode, fiat_shamir_challenge_node: &FiatShamirChallengeNode, ) -> Self
Create a new LookupTable to use for subsequent lookups. (To perform a lookup using this table, create a LookupConstraint.)
Requires:
- The length of the table must be a power of two.
Sourcepub fn add_lookup_constraint(&mut self, constraint: LookupConstraint)
pub fn add_lookup_constraint(&mut self, constraint: LookupConstraint)
Add a lookup constraint to this node. (Will be called by the layouter when laying out the circuit.)
Sourcepub fn generate_lookup_circuit_description<F: Field>(
&self,
circuit_map: &mut CircuitMap,
) -> Result<(Vec<LayerDescriptionEnum<F>>, OutputLayerDescription<F>)>
pub fn generate_lookup_circuit_description<F: Field>( &self, circuit_map: &mut CircuitMap, ) -> Result<(Vec<LayerDescriptionEnum<F>>, OutputLayerDescription<F>)>
Create the circuit description of a lookup node by returning the corresponding circuit descriptions, and output circuit description needed in order to verify the lookup.